/**
 * Knitting pattern from an array
 David McCallum, 2010
 sintheta.org 
 */
 
import processing.pdf.*;
import gifAnimation.*;

PFont fontA;



int[][] inputArray = {  {1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0},
                        {0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0},
                        {0, 0, 0, 1, 0, 1, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0},
                        {0, 1, 1, 1, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0},
                        {0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0},
                        {0, 1, 0, 0, 0, 1, 0, 1, 0, 0, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0},
                        {0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0},
                        {0, 0, 0, 1, 0, 0, 1, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0},
                        {1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0},
                        {0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0},
                        {0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0},
                        {1, 0, 1, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 0},
                     };

int colorBackground = 255;
int colorGrid = 127;
int colorGridPeriod = 200;    // grid colour every 10 blocks
int gridPeriod = 10;
//int colorText = 0;
int gridThickness = 1;

int inputHeight;
int inputWidth;
int screenWidth;
int screenHeight;

String fontName = "CourierNew-12.vlw";
float fontProportion = .6;

int blockSize = 20;      // how big are the cells that we're drawing?


void setup()
{
   inputHeight = inputArray.length;
   inputWidth = inputArray[0].length;
   
   fontA = loadFont(fontName);



  // screen sizing
    
  screenWidth = inputWidth * blockSize;
  screenHeight = inputHeight * blockSize;


  // fonts
  hint(ENABLE_NATIVE_FONTS);

  size(screenWidth,screenHeight); //, PDF, "output.pdf");
  
  background(colorBackground);
  print("Image dimensions: " + inputWidth + " x " + inputHeight + "\n" + 
  "Screen dimensions: " + screenWidth  + " x " +  screenHeight + "\n");
}



void draw()  {
  

  
  //    Draw the image    //
  
  strokeWeight(gridThickness);
  for (int row = inputHeight-1; row >= 0; row--) {
    for (int column = 0; column < inputWidth; column++) {
      if (column % gridPeriod == gridPeriod-1) { stroke(colorGridPeriod); }    // outline every nth column
      else { stroke(colorGrid); }
      fill(inputArray[row][column] * 255);
      rect(column*blockSize, row*blockSize, blockSize, blockSize); 
    }
  }
  
  
  
  //    Write the text    //
  
  textFont(fontA, blockSize * fontProportion);
  for (int row = 1; row <= inputHeight; row++) {
    int offset = int((1.0-fontProportion)*.5 * blockSize);
    int fillColor = 255 - 255*inputArray[inputHeight - row][0];    // "invert" the colour
    fill(fillColor);
    text(row, offset, (inputHeight - row + 1) * blockSize - offset);      // (inputHeight - row + 1) makes it draw from the bottom up
  }
   for (int column = 1; column <= inputWidth; column++) {
    int offset = int((1.0-fontProportion)*.5 * blockSize);
    int fillColor = 255 - 255*inputArray[inputHeight-1][column-1];    // "invert" the colour
    fill(fillColor);
    text(column, column * blockSize + offset - blockSize, inputHeight * blockSize - offset); 
  }
 
  
  
  
  /*
  //    Draw the lines    //
  for (int row = 0; row < inputHeight; row++) {
    stroke(50);
//    line(0, row*blockSize, inputWidth, row*blockSize);
  }

  for (int column = 0; column < inputWidth; column++) {
    
  }
  */
  
  
  
  /*

  for (int j = 0; j <= inputHeight; j++) {  
    for (int i = 0; i <= inputWidth; i++) { 
      color colour = giffer[frame].get((i-1)*pixelsPerpixel, j*pixelsPerpixel); // grab the colour of each block's lower-left pixel
      fill(colour);
      rect(i*blockSize, j*blockSize, blockSize-1, blockSize-1);
      if (i == 0){
         textFont(fontA, blockSize*.5);
         fill(126);
         text(i, i*blockSize, j*blockSize);   
      }
    }
    fill(255);   
    textFont(fontA, blockSize*.5);
    text(inputHeight/pixelsPerpixel-j, blockSize*.05, j*blockSize + blockSize*.5);
  }
    fill(255);
    rect(40*blockSize, 30*blockSize, blockSize*4, blockSize*4 );
    fill(0);
    textFont(fontA, blockSize*3);
    text(frame+1, 40*blockSize, 33*blockSize);

    PGraphicsPDF pdf = (PGraphicsPDF) g;  // Get the renderer
    pdf.nextPage();  // Tell it to go to the next page
    frame++;
    */
}
